Crate hyperlight_common

Crate hyperlight_common 

Modules

arch
cbindgen:ignore
component
cbindgen:ignore Support types for the bindings that {host,guest}_bindgen! generates Support types for the bindings that host_bindgen! generates.
flatbuffer_wrappers
func
cbindgen:ignore
layout
log_level
mem
cbindgen:ignore
outb
cbindgen:ignore
resource
cbindgen:ignore Shared operations around resources
version_note
ELF note types for embedding hyperlight version metadata in guest binaries. ELF note types for embedding hyperlight version metadata in guest binaries.
virtq
cbindgen:ignore Packed Virtqueue Implementation
vmem