pub trait SupportedParameterType:
Sized
+ Clone
+ Send
+ Sync
+ 'static {
const TYPE: ParameterType;
// Required methods
fn into_value(self) -> ParameterValue;
fn from_value(value: ParameterValue) -> Result<Self, Error>;
}Expand description
This is a marker trait that is used to indicate that a type is a valid Hyperlight parameter type.
For each parameter type Hyperlight supports in host functions, we
provide an implementation for SupportedParameterType
Required Associated Constants
Sourceconst TYPE: ParameterType
const TYPE: ParameterType
The underlying Hyperlight parameter type representing this SupportedParameterType
Required Methods
Sourcefn into_value(self) -> ParameterValue
fn into_value(self) -> ParameterValue
Get the underling Hyperlight parameter value representing this
SupportedParameterType
Sourcefn from_value(value: ParameterValue) -> Result<Self, Error>
fn from_value(value: ParameterValue) -> Result<Self, Error>
Get the actual inner value of this SupportedParameterType
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".