Module layout

Module layout 

Constants

MAX_GPA
We assume 36-bit IPAs for now, since every amd64 processor supports at least 36 bits. Almost all of them support at least 40 bits, so we could consider bumping this in the future if we were ever memory-constrained.
MAX_GVA
We have this the top of the page below the top of memory in order to make working with start/end ptrs in a few places more convenient (not needing to worry about overflow)
SCRATCH_TOP_ALLOCATOR_OFFSET
SCRATCH_TOP_EXN_STACK_OFFSET
SCRATCH_TOP_SIZE_OFFSET
SCRATCH_TOP_SNAPSHOT_PT_GPA_BASE_OFFSET
SNAPSHOT_PT_GVA_MAX
SNAPSHOT_PT_GVA_MIN

Functions

min_scratch_size
Compute the minimum scratch region size needed for a sandbox. On amd64, this is:
scratch_base_gpa
scratch_base_gva