GuestLogFilter

Enum GuestLogFilter 

pub enum GuestLogFilter {
    Off,
    Error,
    Warn,
    Info,
    Debug,
    Trace,
}
This type is a unified definition of log level filters between the guest and host.

This is needed because currently the guest uses both the log and tracing crates, and needs each type of LevelFilter from both crates.

To avoid as much as possible the amount of conversions between the two types, we define a single type that can be converted to both log::LevelFilter and tracing_core::LevelFilter. NOTE: This also takes care of the fact that the tracing and log enum types for the log levels are not guaranteed to have the same discriminants, so we can’t just cast between them.

Variants



Off



Error



Warn



Info



Debug



Trace