Module mem

Module mem 

cbindgen:ignore

Structs

FileMappingInfo
Describes a single file mapping in the guest address space.
GuestMemoryRegion
A memory region in the guest address space
HyperlightPEB

Constants

FILE_MAPPING_LABEL_MAX_LEN
Maximum length of a file mapping label (excluding null terminator).
MAX_FILE_MAPPINGS
Maximum number of file mappings that can be registered in the PEB.
PAGE_SHIFT
PAGE_SIZE
PAGE_SIZE_USIZE