pub const fn padded_name_size(name_len_with_nul: usize) -> usizeExpand description
Compute the padded size of the name field for a 64-bit ELF note.
The name must be padded so that the descriptor starts at an 8-byte
aligned offset from the start of the note entry:
(NOTE_HEADER_SIZE + padded_name) % 8 == 0.