UsedChain

Enum UsedChain 

pub enum UsedChain {
    Ack(Token),
    Data(Token, Segments),
}
A used chain observed by the driver (producer) side.

Read-only chains are returned as Ack. Chains with a writable buffer complete as Data, even when the device wrote zero bytes. Non-empty segments in Data are backed by shared-memory pool allocations that are returned when the last clone is dropped.

Variants



Ack(Token)

Acknowledgement for a read-only/fire-and-forget chain.



Data(Token, Segments)

Data written by the consumer into the chain’s writable buffers.

The payload may contain zero bytes when the consumer writes zero bytes; that is still a data used chain because the submitted chain had writable capacity.

Implementations

Source

impl UsedChain

pub fn token(&self) -> Token

Token identifying which submitted chain this used chain corresponds to.

pub fn to_bytes(&self) -> Option<Bytes>

Data written by the consumer as contiguous bytes, if this chain has data.

pub fn segments(&self) -> Option<&Segments>

Segments written by the consumer, if this chain has data.

pub fn into_bytes(self) -> Option<Bytes>

Consume the used chain and return written data as contiguous bytes, if present.

pub fn into_segments(self) -> Option<Segments>

Consume the used chain and return written segments, if present.