BufferChainBuilder

Struct BufferChainBuilder 

pub struct BufferChainBuilder<T> { /* private fields */ }
A builder for buffer chains using type-state to enforce readable/writable order.

Upholds invariants: at least one buffer must be present in the chain, and readable buffers must be added before writable buffers.

The builder stores up to 16 buffer elements inline to avoid allocation for common small chains. Larger chains are still supported and spill to the heap.

Implementations

Source

impl BufferChainBuilder<Readable>

pub fn new() -> Self

Create a new builder in the Readable state.

pub fn readable(self, addr: u64, len: u32) -> Self

Add a readable buffer (device reads from this).

pub fn readables( self, elements: impl IntoIterator<Item = impl Into<BufferElement>>, ) -> Self

Add multiple readable buffers from an iterator.

pub fn writable(self, addr: u64, len: u32) -> BufferChainBuilder<Writable>

Add a writable buffer (device writes to this).

This transitions to Writable state so no more readable buffers can be added.

pub fn writables( self, elements: impl IntoIterator<Item = impl Into<BufferElement>>, ) -> BufferChainBuilder<Writable>

Add multiple writable buffers from an iterator.

This transitions to Writable state so no more readable buffers can be added.

pub fn build(self) -> Result<BufferChain, RingError>

Build a buffer chain with only readable buffers.

Chain must have at least one buffer otherwise an error is returned.

Source

impl BufferChainBuilder<Writable>

pub fn writable(self, addr: u64, len: u32) -> Self

Add writable buffer

pub fn writables( self, elements: impl IntoIterator<Item = impl Into<BufferElement>>, ) -> Self

Add multiple writable buffers from an iterator.

pub fn build(self) -> Result<BufferChain, RingError>

Build the buffer chain.

Chain must have at least one buffer otherwise an error is returned.