pub struct BufferPool<const L: usize = 256, const U: usize = 4096> { /* private fields */ }Expand description
Two tier buffer pool with small and large slabs.
Implementations
Sourceimpl<const L: usize, const U: usize> BufferPool<L, U>
impl<const L: usize, const U: usize> BufferPool<L, U>
Sourceimpl BufferPool
impl BufferPool
Sourcepub const fn upper_slot_size() -> usize
pub const fn upper_slot_size() -> usize
Upper slab slot size in bytes.
Sourcepub const fn lower_slot_size() -> usize
pub const fn lower_slot_size() -> usize
Lower slab slot size in bytes.
Sourceimpl<const L: usize, const U: usize> BufferPool<L, U>
impl<const L: usize, const U: usize> BufferPool<L, U>
Sourcepub fn dealloc_addr(&self, addr: u64) -> Result<(), AllocError>
pub fn dealloc_addr(&self, addr: u64) -> Result<(), AllocError>
Free a previously allocated block by its start address.
Sourcepub fn allocation_len(&self, addr: u64) -> Result<usize, AllocError>
pub fn allocation_len(&self, addr: u64) -> Result<usize, AllocError>
Capacity of a live allocation by its start address.