#[repr(C)]pub struct Descriptor {
pub addr: u64,
pub len: u32,
pub id: u16,
pub flags: u16,
}Fields
addr: u64Physical address of the buffer.
len: u32Length of the buffer in bytes. For used descriptors, this contains bytes written by device.
id: u16Buffer ID - used to correlate completions with submissions. All descriptors in a chain share the same ID.
flags: u16Flags (NEXT, WRITE, INDIRECT, AVAIL, USED).
Implementations
Sourceimpl Descriptor
impl Descriptor
pub const ALIGN: usize = 16
pub const SIZE: usize
pub const ADDR_OFFSET: usize
pub const LEN_OFFSET: usize
pub const ID_OFFSET: usize
pub const FLAGS_OFFSET: usize
pub fn new(addr: u64, len: u32, id: u16, flags: DescFlags) -> Self
Sourcepub fn is_avail(&self, wrap: bool) -> bool
pub fn is_avail(&self, wrap: bool) -> bool
Did the driver make this descriptor available in the current driver round?
Sourcepub fn is_used(&self, wrap: bool) -> bool
pub fn is_used(&self, wrap: bool) -> bool
Did the device mark this descriptor used in the current device round?
Sourcepub fn is_writable(&self) -> bool
pub fn is_writable(&self) -> bool
Is this descriptor writable by the device?
Sourcepub fn mark_avail(&mut self, wrap: bool)
pub fn mark_avail(&mut self, wrap: bool)
Mark descriptor as available according to the driver’s wrap bit. As per the packed-virtqueue description:
- set AVAIL bit to
driver_wrap - set USED bit to
!driver_wrap(inverse)
Sourcepub fn mark_used(&mut self, wrap: bool)
pub fn mark_used(&mut self, wrap: bool)
Mark descriptor as used according to the device’s wrap bit. As per spec: set both USED and AVAIL bits to match device_wrap
Sourcepub fn write_release<M: MemOps>(
&self,
mem: &M,
addr: u64,
) -> Result<(), M::Error>
pub fn write_release<M: MemOps>( &self, mem: &M, addr: u64, ) -> Result<(), M::Error>
Write a descriptor to memory with release semantics for flags at the given base pointer
This is the primary synchronization point for publishing descriptors.
Invariant
The caller must ensure that addr is valid for writes of Descriptor