OwnedAlloc

Struct OwnedAlloc 

pub struct OwnedAlloc<P: BufferProvider> { /* private fields */ }
Pool-owned allocation that is returned to the pool on drop.

Use into_raw to transfer ownership to a descriptor state that will deallocate the raw Allocation through another path.

Implementations

Source

impl<P: BufferProvider> OwnedAlloc<P>

pub fn new(pool: P, alloc: Allocation) -> Self

Wrap an existing allocation with its owning pool.

pub fn allocate(pool: P, len: usize) -> Result<Self, AllocError>

Allocate from pool and return an owning guard.

pub fn allocation(&self) -> Allocation

The raw allocation currently owned by this guard.

pub fn into_raw(self) -> Allocation

Release ownership and return the raw allocation.