pub struct UsedBuffer {
pub id: u16,
pub len: u32,
}Expand description
A buffer returned from the ring after being used by the device.
When the device completes processing a buffer chain, it returns this structure containing the original descriptor ID and the number of bytes written (for chains with writable buffers).
Fields
id: u16Descriptor ID that was assigned when the buffer was submitted
len: u32Number of bytes written by the device to writable buffers. For read-only chains, this may be 0 or the total readable length.