virt_to_phys

Function virt_to_phys 

pub unsafe fn virt_to_phys<'a, Op: TableReadOps + 'a>(
    _op: impl AsRef<Op> + Copy + 'a,
    _address: u64,
    _len: u64,
) -> impl Iterator<Item = Mapping> + 'a
This function is presently used for reading the tracing data, also it is useful for debugging

Safety

This function traverses page table data structures, and should not be called concurrently with any other operations that modify the page table.

Safety

See TableReadOps documentation.