UpdateParentNone

Struct UpdateParentNone 

pub struct UpdateParentNone {}
A struct implementing UpdateParent that is impossible to use (since its UpdateParent::update_parent method takes Void), used when it is statically known that a table operation cannot result in a need to update ancestors.