Crate hyperlight_common
hyperlight_
common
0.17.0
All Items
Crate Items
Modules
Crate
hyperlight_
common
Modules

arch
cbindgen:ignore
component
cbindgen:ignore Support types for the bindings that
{host,guest}_bindgen!
generates Support types for the bindings that
host_bindgen!
generates.
flatbuffer_
wrappers
func
cbindgen:ignore
layout
log_
level
mem
cbindgen:ignore
outb
cbindgen:ignore
resource
cbindgen:ignore Shared operations around resources
version_
note
ELF note types for embedding hyperlight version metadata in guest binaries. ELF note types for embedding hyperlight version metadata in guest binaries.
virtq
cbindgen:ignore Packed Virtqueue Implementation
vmem