cbindgen:ignore
Support types for the bindings that {host,guest}_bindgen! generates
Support types for the bindings that host_bindgen! generates.
Enums
- Negative
- A type is being used in a negative position in the overall type: it is implemented by the host, and the guest calls it.
- Positive
- A type is being used in a positive position in the overall type: it is implemented by the guest, and the host calls it.
Traits
- Positivity
- Whether an instance/resource/etc is being used in a positive or negative position in the top-level component type that governs the interface. That is to say, whether the functions provided by this instance/resource (or exported by this component) are expected to be implemented in the guest and called on the host or vice versa.