cbindgen:ignore
Structs
- File
Mapping Info - Describes a single file mapping in the guest address space.
- Guest
Memory Region - A memory region in the guest address space
- HyperlightPEB
Constants
- FILE_
MAPPING_ LABEL_ MAX_ LEN - Maximum length of a file mapping label (excluding null terminator).
- MAX_
FILE_ MAPPINGS - Maximum number of file mappings that can be registered in the PEB.
- PAGE_
SHIFT - PAGE_
SIZE - PAGE_
SIZE_ USIZE