cbindgen:ignore
Enums
- Exception
- Exception codes for the x86 architecture. These are helpful to identify the type of exception that occurred together with OutBAction::Abort.
- OutB
Action - Supported actions when issuing an OUTB actions by Hyperlight. These are handled by the sandbox-level outb dispatcher.
- VmAction
- IO-port actions intercepted at the hypervisor level (in
run_vcpu) before they ever reach the sandbox outb handler. These are split fromOutBActionso the outb handler does not need unreachable match arms for ports it can never see.