pub const fn padded_desc_size(desc_len_with_nul: usize) -> usizeExpand description
Compute the padded size of the descriptor field for a 64-bit ELF note.
The descriptor must be padded so that the next note entry starts at
an 8-byte aligned offset: padded_desc % 8 == 0.