BufferPool

Struct BufferPool 

pub struct BufferPool<const L: usize = 256, const U: usize = 4096> { /* private fields */ }
Two tier buffer pool with small and large slabs.

Implementations

Source

impl<const L: usize, const U: usize> BufferPool<L, U>

pub fn new(base_addr: u64, region_len: usize) -> Result<Self, AllocError>

Create a new buffer pool over a fixed region.

Source

impl BufferPool

pub const fn upper_slot_size() -> usize

Upper slab slot size in bytes.

pub const fn lower_slot_size() -> usize

Lower slab slot size in bytes.

Source

impl<const L: usize, const U: usize> BufferPool<L, U>

pub fn dealloc_addr(&self, addr: u64) -> Result<(), AllocError>

Free a previously allocated block by its start address.

pub fn allocation_len(&self, addr: u64) -> Result<usize, AllocError>

Capacity of a live allocation by its start address.