pub struct EventSuppression { /* private fields */ }Expand description
Event suppression structure for controlling notifications.
Implementations
Sourceimpl EventSuppression
impl EventSuppression
pub const SIZE: usize
pub const ALIGN: usize
pub const WRAP_OFFSET: usize
pub const FLAGS_OFFSET: usize
Sourcepub fn new(off_wrap: u16, flags: EventFlags) -> Self
pub fn new(off_wrap: u16, flags: EventFlags) -> Self
Create a new event suppression with the given offset/wrap and flags.
Sourcepub fn flags(&self) -> EventFlags
pub fn flags(&self) -> EventFlags
Get the event flags.
Sourcepub fn set_flags(&mut self, flags: EventFlags)
pub fn set_flags(&mut self, flags: EventFlags)
Set the event flags.
Sourcepub fn desc_event_off(&self) -> u16
pub fn desc_event_off(&self) -> u16
Get the descriptor event offset (bits 0-14).
Sourcepub fn desc_event_wrap(&self) -> bool
pub fn desc_event_wrap(&self) -> bool
Check if the descriptor event wrap bit (bit 15) is set.
Sourcepub fn set_desc_event(&mut self, off: u16, wrap: bool)
pub fn set_desc_event(&mut self, off: u16, wrap: bool)
Set the descriptor event offset and wrap bit.
Sourcepub fn read_flags_acquire<M: MemOps>(
mem: &M,
addr: u64,
) -> Result<EventFlags, M::Error>
pub fn read_flags_acquire<M: MemOps>( mem: &M, addr: u64, ) -> Result<EventFlags, M::Error>
Acquire-load only the flags word - the publish point - without reading
the off_wrap payload.
Invariant
The caller must ensure that addr is a valid pointer to an EventSuppression.
Sourcepub fn read_body<M: MemOps>(
mem: &M,
addr: u64,
flags: EventFlags,
) -> Result<Self, M::Error>
pub fn read_body<M: MemOps>( mem: &M, addr: u64, flags: EventFlags, ) -> Result<Self, M::Error>
Read the off_wrap payload and combine it with flags already obtained
from read_flags_acquire.
Invariant
The caller must ensure that addr is a valid pointer to an EventSuppression.