pub struct OwnedAlloc<P: BufferProvider> { /* private fields */ }Expand description
Pool-owned allocation that is returned to the pool on drop.
Use into_raw to transfer ownership to a descriptor
state that will deallocate the raw Allocation through another path.
Implementations
Sourceimpl<P: BufferProvider> OwnedAlloc<P>
impl<P: BufferProvider> OwnedAlloc<P>
Sourcepub fn new(pool: P, alloc: Allocation) -> Self
pub fn new(pool: P, alloc: Allocation) -> Self
Wrap an existing allocation with its owning pool.
Sourcepub fn allocate(pool: P, len: usize) -> Result<Self, AllocError>
pub fn allocate(pool: P, len: usize) -> Result<Self, AllocError>
Allocate from pool and return an owning guard.
Sourcepub fn allocation(&self) -> Allocation
pub fn allocation(&self) -> Allocation
The raw allocation currently owned by this guard.
Sourcepub fn into_raw(self) -> Allocation
pub fn into_raw(self) -> Allocation
Release ownership and return the raw allocation.