The operations used to actually access the page table structures
that involve writing to them, used to allow the same code to be
used in the host and the guest for page table setup.
The read-only operations used to actually access the page table
structures, used to allow the same code to be used in the host and
the guest for page table setup. This is distinct from
TableWriteOps, since there are some implementations for which
writing does not make sense, and only reading is required.