map

Function map 

pub unsafe fn map<Op: TableOps>(_op: &Op, _mapping: Mapping)
Assumption: all are page-aligned

Safety

This function modifies pages backing a virtual memory range which is inherently unsafe w.r.t. the Rust memory model.

When using this function, please note:

  • No locking is performed before touching page table data structures, as such do not use concurrently with any other page table operations
  • TLB invalidation is not performed, if previously-mapped ranges are being remapped, TLB invalidation may need to be performed afterwards.

Safety

See TableOps documentation.