pub unsafe fn virt_to_phys<'a, Op: TableReadOps + 'a>(
op: impl AsRef<Op> + Copy + 'a,
address: u64,
len: u64,
) -> impl Iterator<Item = Mapping> + 'aExpand description
This function is presently used for reading the tracing data, also it is useful for debugging
Safety
This function traverses page table data structures, and should not be called concurrently with any other operations that modify the page table. Translates a virtual address range to the physical address pages that back it by walking the page tables.
Returns an iterator with an entry for each mapped page that intersects the given range.
This takes AsRef