pub type SpaceId = u64;Expand description
Identifier for a virtual address space, used by the multi-space walker to describe which space “owns” a shared intermediate table. Implementations typically use the physical address of the root page table (which is unique per space).